==> qcad-3.32.4.0-1-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation type="unfinished">垂直/水平</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation type="unfinished">返回</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>自定义</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>网格</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>终点</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation type="unfinished">在实体</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>正交</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>正切</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>居中</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>相交</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>参考</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation type="unfinished">距离</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>无效</translation>
    </message>
</context>
</TS>

==> qcad-3.32.4.4-3-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>垂直/水平</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>返回</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>自定义</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>网格</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>终点</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>实体上</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>正交</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>正切</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>居中</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>相交</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>参考</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>无效</translation>
    </message>
</context>
</TS>
